@@ -46,5 +46,7 @@ from .function import (
     lower_confidence_bound,
     ProbabilityOfFeasibility,
     probability_of_feasibility,
+    ExpectedConstrainedImprovement,
+    IndependentReparametrizationSampler,
 )
 from .combination import Reducer, Product, Sum
